@@ -1,10 +1,6 @@
-"""
-============================
-WebServices Client API
-============================
+"""Client for GeoIP2 and GeoLite2 web services.
 
-This class provides a client API for all the GeoIP2 web services. The web
-services are Country, City Plus, and Insights. Each service returns a
+The web services are Country, City Plus, and Insights. Each service returns a
 different set of data about an IP address, with Country returning the least
 data and Insights the most.
 
@@ -27,7 +23,8 @@ Requests to the web service are always made with SSL.
 
 import ipaddress
 import json
-from typing import Any, Dict, cast, List, Optional, Type, Union
+from collections.abc import Sequence
+from typing import Any, Optional, Union, cast
 
 import aiohttp
 import aiohttp.http
@@ -61,7 +58,7 @@ class BaseClient:  # pylint: disable=missing-class-docstring, too-few-public-met
     _account_id: str
     _host: str
     _license_key: str
-    _locales: List[str]
+    _locales: Sequence[str]
     _timeout: float
 
     def __init__(
@@ -69,7 +66,7 @@ class BaseClient:  # pylint: disable=missing-class-docstring, too-few-public-met
         account_id: int,
         license_key: str,
         host: str,
-        locales: Optional[List[str]],
+        locales: Optional[Sequence[str]],
         timeout: float,
     ) -> None:
         """Construct a Client."""
@@ -106,7 +103,11 @@ class BaseClient:  # pylint: disable=missing-class-docstring, too-few-public-met
             ) from ex
 
     def _exception_for_error(
-        self, status: int, content_type: str, body: str, uri: str
+        self,
+        status: int,
+        content_type: str,
+        body: str,
+        uri: str,
     ) -> GeoIP2Error:
         if 400 <= status < 500:
             return self._exception_for_4xx_status(status, content_type, body, uri)
@@ -115,7 +116,11 @@ class BaseClient:  # pylint: disable=missing-class-docstring, too-few-public-met
         return self._exception_for_non_200_status(status, uri, body)
 
     def _exception_for_4xx_status(
-        self, status: int, content_type: str, body: str, uri: str
+        self,
+        status: int,
+        content_type: str,
+        body: str,
+        uri: str,
     ) -> GeoIP2Error:
         if not body:
             return HTTPError(
@@ -145,7 +150,10 @@ class BaseClient:  # pylint: disable=missing-class-docstring, too-few-public-met
 
         if "code" in decoded_body and "error" in decoded_body:
             return self._exception_for_web_service_error(
-                decoded_body.get("error"), decoded_body.get("code"), status, uri
+                decoded_body.get("error"),
+                decoded_body.get("code"),
+                status,
+                uri,
             )
         return HTTPError(
             "Response contains JSON but it does not specify code or error keys",
@@ -156,7 +164,10 @@ class BaseClient:  # pylint: disable=missing-class-docstring, too-few-public-met
 
     @staticmethod
     def _exception_for_web_service_error(
-        message: str, code: str, status: int, uri: str
+        message: str,
+        code: str,
+        status: int,
+        uri: str,
     ) -> Union[
         AuthenticationError,
         AddressNotFoundError,
@@ -184,7 +195,9 @@ class BaseClient:  # pylint: disable=missing-class-docstring, too-few-public-met
 
     @staticmethod
     def _exception_for_5xx_status(
-        status: int, uri: str, body: Optional[str]
+        status: int,
+        uri: str,
+        body: Optional[str],
     ) -> HTTPError:
         return HTTPError(
             f"Received a server error ({status}) for {uri}",
@@ -195,7 +208,9 @@ class BaseClient:  # pylint: disable=missing-class-docstring, too-few-public-met
 
     @staticmethod
     def _exception_for_non_200_status(
-        status: int, uri: str, body: Optional[str]
+        status: int,
+        uri: str,
+        body: Optional[str],
     ) -> HTTPError:
         return HTTPError(
             f"Received a very surprising HTTP status ({status}) for {uri}",
@@ -265,7 +280,7 @@ class AsyncClient(BaseClient):
         account_id: int,
         license_key: str,
         host: str = "geoip.maxmind.com",
-        locales: Optional[List[str]] = None,
+        locales: Optional[Sequence[str]] = None,
         timeout: float = 60,
         proxy: Optional[str] = None,
     ) -> None:
@@ -289,7 +304,8 @@ class AsyncClient(BaseClient):
 
         """
         return cast(
-            City, await self._response_for("city", geoip2.models.City, ip_address)
+            City,
+            await self._response_for("city", geoip2.models.City, ip_address),
         )
 
     async def country(self, ip_address: IPAddress = "me") -> Country:
@@ -338,7 +354,7 @@ class AsyncClient(BaseClient):
     async def _response_for(
         self,
         path: str,
-        model_class: Union[Type[Insights], Type[City], Type[Country]],
+        model_class: Union[type[Insights], type[City], type[Country]],
         ip_address: IPAddress,
     ) -> Union[Country, City, Insights]:
         uri = self._uri(path, ip_address)
@@ -350,10 +366,10 @@ class AsyncClient(BaseClient):
             if status != 200:
                 raise self._exception_for_error(status, content_type, body, uri)
             decoded_body = self._handle_success(body, uri)
-            return model_class(decoded_body, locales=self._locales)
+            return model_class(self._locales, **decoded_body)
 
-    async def close(self):
-        """Close underlying session
+    async def close(self) -> None:
+        """Close underlying session.
 
         This will close the session and any associated connections.
         """
@@ -421,14 +437,14 @@ class Client(BaseClient):
     """
 
     _session: requests.Session
-    _proxies: Optional[Dict[str, str]]
+    _proxies: Optional[dict[str, str]]
 
     def __init__(  # pylint: disable=too-many-arguments,too-many-positional-arguments
         self,
         account_id: int,
         license_key: str,
         host: str = "geoip.maxmind.com",
-        locales: Optional[List[str]] = None,
+        locales: Optional[Sequence[str]] = None,
         timeout: float = 60,
         proxy: Optional[str] = None,
     ) -> None:
@@ -465,7 +481,8 @@ class Client(BaseClient):
 
         """
         return cast(
-            Country, self._response_for("country", geoip2.models.Country, ip_address)
+            Country,
+            self._response_for("country", geoip2.models.Country, ip_address),
         )
 
     def insights(self, ip_address: IPAddress = "me") -> Insights:
@@ -482,13 +499,14 @@ class Client(BaseClient):
 
         """
         return cast(
-            Insights, self._response_for("insights", geoip2.models.Insights, ip_address)
+            Insights,
+            self._response_for("insights", geoip2.models.Insights, ip_address),
         )
 
     def _response_for(
         self,
         path: str,
-        model_class: Union[Type[Insights], Type[City], Type[Country]],
+        model_class: Union[type[Insights], type[City], type[Country]],
         ip_address: IPAddress,
     ) -> Union[Country, City, Insights]:
         uri = self._uri(path, ip_address)
@@ -499,10 +517,10 @@ class Client(BaseClient):
         if status != 200:
             raise self._exception_for_error(status, content_type, body, uri)
         decoded_body = self._handle_success(body, uri)
-        return model_class(decoded_body, locales=self._locales)
+        return model_class(self._locales, **decoded_body)
 
-    def close(self):
-        """Close underlying session
+    def close(self) -> None:
+        """Close underlying session.
 
         This will close the session and any associated connections.
         """
